@@ -49,7 +49,8 @@ public class IFTTTWorkitemHandlerTest {
 
         when(client.target(anyString())).thenReturn(webTarget);
         when(webTarget.request()).thenReturn(builder);
-        when(builder.post(any(Entity.class),any(Class.class))).thenReturn(new String("testResponse"));
+        when(builder.post(any(Entity.class),
+                          any(Class.class))).thenReturn(new String("testResponse"));
     }
 
     @Test
@@ -76,7 +77,7 @@ public class IFTTTWorkitemHandlerTest {
                      manager.getResults().size());
         assertTrue(manager.getResults().containsKey(workItem.getId()));
 
-        String testValueJSONString = "{\"value1\":\"testValue1\",\"value2\":\"testValue1\",\"value3\":\"testValue1\"}";
+        String testValueJSONString = "{\"value1\":\"testValue1\",\"value2\":\"testValue2\",\"value3\":\"testValue3\"}";
         assertEquals(testValueJSONString,
                      handler.getRequestBody());
     }
