@@ -67,9 +67,9 @@ public class KafkaWorkItemHandler extends AbstractLogOrThrowWorkItemHandler impl
 
     private static final Logger LOG = LoggerFactory.getLogger(KafkaWorkItemHandler.class);
 
-    private Producer<Long, String> producer;
+    private Producer<String, String> producer;
     private static final String RESULTS_VALUE = "Result";
-
+    
     public KafkaWorkItemHandler(Producer producer) {
         this.producer = producer;
     }
@@ -77,7 +77,8 @@ public class KafkaWorkItemHandler extends AbstractLogOrThrowWorkItemHandler impl
     public KafkaWorkItemHandler(String bootstrapServers,
                                 String clientId,
                                 String keySerializerClass,
-                                String valueSerializerClass) {
+                                String valueSerializerClass,
+                                ClassLoader classLoader) {
         Properties config = new Properties();
         config.put(ProducerConfig.BOOTSTRAP_SERVERS_CONFIG,
                    bootstrapServers);
@@ -87,7 +88,22 @@ public class KafkaWorkItemHandler extends AbstractLogOrThrowWorkItemHandler impl
                    keySerializerClass);
         config.put(ProducerConfig.VALUE_SERIALIZER_CLASS_CONFIG,
                    valueSerializerClass);
-        producer = new KafkaProducer<Long, String>(config);
+        // it is needed to change the classloader to KIEURLClassLoader for dependencies to be resolved and then, set it back
+        ClassLoader oldClassLoader = Thread.currentThread().getContextClassLoader();
+        try {
+          Thread.currentThread().setContextClassLoader(classLoader);
+          producer = new KafkaProducer<String, String>(config);
+        } finally {
+          Thread.currentThread().setContextClassLoader(oldClassLoader);
+        }
+    }
+
+    public KafkaWorkItemHandler(String bootstrapServers,
+                                String clientId,
+                                String keySerializerClass,
+                                String valueSerializerClass) {
+
+        this(bootstrapServers, clientId, keySerializerClass, valueSerializerClass, KafkaProducer.class.getClassLoader());
     }
 
     public void executeWorkItem(WorkItem workItem,
@@ -99,25 +115,16 @@ public class KafkaWorkItemHandler extends AbstractLogOrThrowWorkItemHandler impl
 
             Map<String, Object> results = new HashMap<String, Object>();
             String topic = (String) workItem.getParameter("Topic");
-            String key = (String) workItem.getParameter("Key");
-            String value = (String) workItem.getParameter("Value");
+            Object key = workItem.getParameter("Key");
+            Object value = workItem.getParameter("Value");
 
-            try {
+            producer.send(new ProducerRecord(topic, 
+                                             key, 
+                                             value))
+                    .get();
 
-                producer.send(new ProducerRecord(topic,
-                                                 key,
-                                                 value));
-                results.put(RESULTS_VALUE,
-                            "success");
-                manager.completeWorkItem(workItem.getId(),
-                                         results);
-            } catch (Exception e) {
-                LOG.error("Kafka error",
-                          e);
-                producer.flush();
-                results.put(RESULTS_VALUE,
-                            "failure");
-            }
+            results.put(RESULTS_VALUE, "success");
+            manager.completeWorkItem(workItem.getId(), results);
         } catch (Exception exp) {
             LOG.error("Handler error",
                       exp);
